@@ -1,6 +1,7 @@
 import asyncio
 import functools
 import sys
+from networktools.colorprint import gprint, bprint, rprint
 
 VERSION = sys.version_info
 
@@ -9,8 +10,31 @@ async def pause(sleep, *args, **kwargs):
     await asyncio.sleep(sleep)
     return [sleep, *args], kwargs
 
+from typing import (
+    List,
+    Tuple,
+    Dict,
+    Any,
+    Callable)
 
-async def coromask(coro, args, kwargs, fargs):
+# from collections.abc import (Coroutine, Awaitable, Callable)
+# from mypy_extensions import Expand
+
+# ArgsInput = List[Any]
+# KwargsInput = Dict[str, Any]
+# ArgsOutput = List[Any]
+# KwargsOutput = Dict[str, Any]
+# AllInput = Tuple[]
+# ResultOutput = Tuple[ArgsOutput, KwargsOutput]
+# AwaitableResult = Awaitable[]
+# CoroutineFunctionInput = Callable[[Expand[ArgsInput],
+#                                    Expand[KwargsInput]], ]]
+
+async def coromask(
+        coro,
+        args,
+        kwargs,
+        fargs):
     """
     A coroutine that mask another coroutine  callback with args, and a
     function callbacks who manage input/output of corotine callback
@@ -24,16 +48,16 @@ async def coromask(coro, args, kwargs, fargs):
     """
     try:
         _in = args
-        msg = ("Coromask args %s, kwargs %s, in coro %s" %
-               (args, kwargs, coro))
+        msg = f"Coromask args {args}, kwargs {kwargs}, in coro {coro}"
         obtained = await coro(*args, **kwargs)
-        if isinstance(obtained, Exception):
-            raise Exception()
-        else:
-            result = fargs(_in, obtained)
-            return result
+        result = fargs(_in, obtained)
+        return result
     except Exception:
         raise Exception(msg)
+    except asyncio.TimeoutError as te:
+        raise te
+    except asyncio.CancelledError as ce:
+        raise ce
 
 
 def renew(task, coro, fargs, *args, **kwargs):
@@ -60,14 +84,12 @@ def renew(task, coro, fargs, *args, **kwargs):
             else:
                 return "STOPPED"
         except asyncio.InvalidStateError as ie:
-            print("Invalid State Error", ie, "Coro", coro, "args", args,
-                  "kargs", kwargs)
+            msg = f"Coro {coro} args {args} kargs {kwargs}"
+            print(msg, ie)
             raise ie
         except Exception as e:
-            print(
-                f"Resultado  cancelled {task.cancelled()}, {task}, coro {coro}, fargs {fargs}"
-            )
-            print("Excepcion en renew", e)
+            msg = f"Resultado  cancelled {task.cancelled()}, {task}, coro {coro}, fargs {fargs}" 
+            print(msg, e)
             raise e
     else:
         try:
@@ -229,7 +251,7 @@ class TaskLoop:
                     if VERSION.major == 3 and VERSION.minor >= 8:
                         task = loop.create_task(
                             coromask(coro, result_args,
-                                     result_kwargs, fargs))
+                                     result_kwargs, fargs), name=self._name)
                     if VERSION.major == 3 and VERSION.minor == 7:
                         task = loop.create_task(
                             coromask(coro, result_args,
@@ -243,13 +265,17 @@ class TaskLoop:
                     if VERSION.major == 3 and VERSION.minor >= 8:
                         task = loop.create_task(
                             coromask(pause, pause_args,
-                                     pause_kwargs, fargs))
+                                     pause_kwargs, fargs), name=self._name)
                     if VERSION.major == 3 and VERSION.minor == 7:
                         task = loop.create_task(
                             coromask(pause, pause_args,
                                      pause_kwargs, fargs))
                     task.add_done_callback(
-                        functools.partial(self.renew, task, pause, fargs))
+                        functools.partial(self.renew, task, pause,
+                                          fargs))
+            except asyncio.CancelledError as ce:
+                rprint(f"Error de cancelación fargs {fargs}")
+                raise ce
             except asyncio.IncompleteReadError as incomplete_read:
                 print("IncompleteReadError {incomplete_read}")
                 print("Result incomplete: {incomplete_read.partial}")
